@@ -15,7 +15,7 @@ class dump(Command):
         values = {}
         for opt in ['name', 'version', 'description', 'author', 'author_email',
                     'license', 'long_description', 'keywords', 'url',
-                    'classifier']:
+                    'classifiers']:
             try:
                 values[opt] = getattr(self.distribution.metadata, opt)
             except AttributeError:
