@@ -22,10 +22,10 @@ def smart_write(fpath, content):
 def smart_symlink(src, dst):
     if os.path.islink(dst):
         if os.readlink(dst) == src: return False
-        os.remove(dst)
+        os.unlink(dst)
     elif os.path.isfile(dst):
         if filecmp.cmp(dst, src): return False
-        os.remove(dst)
+        os.unlink(dst)
     os.symlink(src, dst)
     return True
 
@@ -33,3 +33,11 @@ def uniq_extend(result, added):
     for a in added:
         if a not in result: result.append(a)
     return result
+
+def cut_parentheses(value):
+    retvalue = ''; lvl = 0
+    for ch in value:
+        if ch == '(': lvl = lvl + 1
+        elif ch == ')': lvl = lvl - 1
+        elif lvl == 0: retvalue = retvalue + ch
+    return retvalue
